svg {
  width: 100%;
  height: 500px;
}

.wy-nav-content {
  max-width: none;
}

.jupyter-widgets.widget-tab>.p-TabBar>.p-TabBar-content {
  visibility: hidden;
}

.widget-tab-bar {
  display: none;
}
